==> proc-10.1.27.tar.gz: proc/src/Controller/ProcAjaxModalMsgController.php <==
<?php

namespace Drupal\proc\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Path\CurrentPathStack;
use Drupal\Core\Session\AccountProxy;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\Request;

/**
 * Proc Ajax Modal Message controller.
 *
 * @see \Drupal\Core\Controller\ControllerBase
 */
class ProcAjaxModalMsgController extends ControllerBase {

  /**
   * The current user.
   *
   * @var \Drupal\Core\Session\AccountProxy
   */
  protected AccountProxy $current_user;

  /**
   * The current path.
   *
   * @var \Drupal\Core\Path\CurrentPathStack
   */
  protected CurrentPathStack $current_path;

  /**
   * The current request.
   *
   * @var \Symfony\Component\HttpFoundation\Request
   */
  protected Request $current_request;

  /**
   * ProcController controller.
   *
   * @param \Drupal\Core\Session\AccountProxy $current_user
   *   The file repository.
   *
   * @param \Drupal\Core\Path\CurrentPathStack $current_path
   *   The current path.
   *
   * @param Symfony\Component\HttpFoundation\Request $current_request
   *   The current request.
   */
  public function __construct(AccountProxy $current_user, CurrentPathStack $current_path, Request $request) {
    $this->currentUser = $current_user;
    $this->currentPath = $current_path;
    $this->request = $request;
  }

  /**
   * {@inheritdoc}
   *
   * @param \Symfony\Component\DependencyInjection\ContainerInterface $container
   *   The Drupal service container.
   *
   * @return static
   */
  public static function create(ContainerInterface $container): static {
    return new static(
      $container->get('current_user'),
      $container->get('path.current'),
      $container->get('request_stack')->getCurrentRequest()
    );
  }

  /**
   * Build the Proc dialog confirmation message.
   *
   * @return array
   *   The render array defining the elements of the page.
   */
  public function printMessage() : array {

    $message = '';
    if ($this->request->query->has('msg')) {
      $message = $this->request->query->get('msg');
    }

    $build['message'] = [
      '#type' => 'markup',
      '#markup' => $message,
    ];

    return $build;
  }

}

==> proc-10.1.28.tar.gz: proc/src/Controller/ProcAjaxModalMsgController.php <==
<?php

namespace Drupal\proc\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Path\CurrentPathStack;
use Drupal\Core\Session\AccountProxy;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\Request;

/**
 * Proc Ajax Modal Message controller.
 *
 * @see \Drupal\Core\Controller\ControllerBase
 */
class ProcAjaxModalMsgController extends ControllerBase {

  /**
   * The current path.
   *
   * @var \Drupal\Core\Path\CurrentPathStack
   */
  protected CurrentPathStack $currentPath;

  /**
   * The current request.
   *
   * @var \Symfony\Component\HttpFoundation\Request
   */
  protected Request $request;

  /**
   * ProcController controller.
   *
   * @param \Drupal\Core\Session\AccountProxy $current_user
   *   The file repository.
   * @param \Drupal\Core\Path\CurrentPathStack $current_path
   *   The current path.
   * @param Symfony\Component\HttpFoundation\Request $request
   *   The current request.
   */
  public function __construct(AccountProxy $current_user, CurrentPathStack $current_path, Request $request) {
    $this->currentUser = $current_user;
    $this->currentPath = $current_path;
    $this->request = $request;
  }

  /**
   * {@inheritdoc}
   *
   * @param \Symfony\Component\DependencyInjection\ContainerInterface $container
   *   The Drupal service container.
   *
   * @return static
   */
  public static function create(ContainerInterface $container): static {
    return new static(
      $container->get('current_user'),
      $container->get('path.current'),
      $container->get('request_stack')->getCurrentRequest()
    );
  }

  /**
   * Build the Proc dialog confirmation message.
   *
   * @return array
   *   The render array defining the elements of the page.
   */
  public function printMessage() : array {

    $message = '';
    if ($this->request->query->has('msg')) {
      $message = $this->request->query->get('msg');
    }

    $build['message'] = [
      '#type' => 'markup',
      '#markup' => $message,
    ];

    return $build;
  }

}
